summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSenko Rasic <senko.rasic@collabora.co.uk>2010-04-13 13:42:26 +0200
committerSimon McVittie <simon.mcvittie@collabora.co.uk>2010-04-15 19:16:13 +0100
commitfb0dc6853ac6109da9aaa11f5b9c464379613ff4 (patch)
tree5adb666d6713bc3cd97196dcfe526ea5ee7e9087
parent3fa338d7411638dea87f0e30ba2ff9b920905333 (diff)
downloadtelepathy-mission-control-fb0dc6853ac6109da9aaa11f5b9c464379613ff4.tar.gz
tests: assert that observer info "recovering" key is set in observer recovery
-rw-r--r--test/twisted/dispatcher/respawn-activatable-observers.py4
-rw-r--r--test/twisted/dispatcher/respawn-observers.py4
2 files changed, 6 insertions, 2 deletions
diff --git a/test/twisted/dispatcher/respawn-activatable-observers.py b/test/twisted/dispatcher/respawn-activatable-observers.py
index 923fc4b4..8f83ffbb 100644
--- a/test/twisted/dispatcher/respawn-activatable-observers.py
+++ b/test/twisted/dispatcher/respawn-activatable-observers.py
@@ -215,10 +215,12 @@ def test(q, bus, mc):
handled=False)
# FIXME: assert the same things as before, except CDO (which we don't
# have) and account path (which we don't know how to get)
assert e.args[0] == account.object_path, e.args
assert e.args[1] == conn.object_path, e.args
assert e.args[4] == [], e.args # no requests satisfied
+ assert e.args[5]['recovering'] == 1, e.args # due to observer recovery
channels = e.args[2]
assert len(channels) == 1, channels
assert channels[0][0] == chan.object_path, channels
@@ -215,10 +215,12 @@ def test(q, bus, mc):
handled=False)
# FIXME: assert the same things as before, except CDO (which we don't
- # have) and account path (which we don't know how to get)
+ # have) and account path (which we don't know how to get); also check
+ # that the recovering observer info key is set
assert e.args[0] == account.object_path, e.args
assert e.args[1] == conn.object_path, e.args
diff --git a/test/twisted/dispatcher/respawn-observers.py b/test/twisted/dispatcher/respawn-observers.py
index e1e31a3b..73847bec 100644
--- a/test/twisted/dispatcher/respawn-observers.py
+++ b/test/twisted/dispatcher/respawn-observers.py
@@ -200,10 +200,12 @@ def test(q, bus, mc):
handled=False)
# FIXME: assert the same things as before, except CDO (which we don't
# have) and account path (which we don't know how to get)
assert e.args[0] == account.object_path, e.args
assert e.args[1] == conn.object_path, e.args
assert e.args[4] == [], e.args # no requests satisfied
+ assert e.args[5]['recovering'] == 1, e.args # due to observer recovery
channels = e.args[2]
assert len(channels) == 1, channels
assert channels[0][0] == chan.object_path, channels
@@ -200,10 +200,12 @@ def test(q, bus, mc):
handled=False)
# FIXME: assert the same things as before, except CDO (which we don't
- # have) and account path (which we don't know how to get)
+ # have) and account path (which we don't know how to get); also check
+ # that the recovering observer info key is set
assert e.args[0] == account.object_path, e.args
assert e.args[1] == conn.object_path, e.args